Dominance Analysis Package

This package can be used for dominance analysis or Shapley Value Regression for finding relative importance of predictors on given dataset. This library can be used for key driver analysis or marginal resource allocation models.

Please follow github repository for the detailed description [here](https://dominance-analysis.github.io/dominance-analysis) and the official documentation [here](https://dominance-analysis.readthedocs.io/en/latest/index.html).